# This file was auto-generated by Fern from our API Definition.

import typing

BusinessPurposeStandard = typing.Union[
    typing.Literal[
        "CNAE2",
        "ISIC3",
        "ISIC31",
        "ISIC4",
        "JSIC13",
        "KSIC10",
        "NACE1",
        "NACE2",
        "NAICS2017",
        "SKD2002",
        "SKD2008",
        "TSIC2552",
        "NACEBEL2003",
        "NACEBEL2008",
        "NAF1",
        "NAF2",
        "GCED2011",
        "SCIAN2018",
        "CCNAE2021",
        "CAEM2005",
        "SBI2008",
        "HS",
        "SIC",
        "SSIC2020",
        "PKD2007",
        "ESA2010",
        "ATECO",
        "CAE",
        "TOL2008",
        "ADGM",
        "NIC2008",
    ],
    typing.Any,
]
