# This file was auto-generated by Fern from our API Definition.

import typing

AddressType = typing.Union[
    typing.Literal["arrival", "departure", "mailing", "physical", "registered", "business"], typing.Any
]
