# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .project_share_on_create import ProjectShareOnCreate
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class CreateProjectRequest(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.project import CreateProjectRequest

    CreateProjectRequest(
        label="Project Alpha",
    )
    """

    label: str
    share: typing.Optional[ProjectShareOnCreate] = pydantic.Field(default=None)
    """
    Specifies access levels available to users in a project within an organization. For comprehensive access, the admin role is recommended.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
