# This file was auto-generated by Fern from our API Definition.

from ...core.api_error import ApiError
from ..types.bad_gateway_response import BadGatewayResponse


class BadGateway(ApiError):
    def __init__(self, body: BadGatewayResponse):
        super().__init__(status_code=502, body=body)
