# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .entity_response_data import EntityResponseData
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class DeleteResourceResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.resource import DeleteResourceResponse, EntityResponseData

    DeleteResourceResponse(
        data=EntityResponseData(
            type="entity",
            id="YWmNKV",
            project="YWmNKV",
            label="HOME DEPOT, U. S. A., INC.",
            created="2024-04-24 14:24:14.07741+00",
            updated="2024-04-24 14:24:14.07741+00",
            updated_by="auth0|5e45bd8caccd890e68147513",
            version=0,
            entity_id="n9SA4T_33tDmLtS8BhC6Zg",
            tag_ids=[],
            case_status="not_assigned",
        ),
    )
    """

    data: EntityResponseData

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
